@@ -29,17 +29,21 @@ def validate_match_columns(import_log, model_class, header_row):
     field_names = model_class._meta.get_all_field_names()
     for field_name in field_names:
         field_object, model, direct, m2m = model_class._meta.get_field_by_name(field_name)
-        if direct and model and not field_object.blank and import_log.import_type != "O": # Skip if Update Only
-            field_matches = column_matches.filter(field_name=field_name)
-            match_in_header = False
-            if field_matches:
-                for field_match in field_matches:
-                    if field_match.column_name.lower() in header_row:
-                        match_in_header = True
-                if not match_in_header:
-                    errors += ["{0} is required but is not in your spreadsheet. ".format(field_object.verbose_name)]
-            else:
-                errors += ["{0} is required but has no match.".format(field_object.verbose_name)]
+        # Skip if update only and skip ptr which suggests it's a django inherited field
+        # Also some hard coded ones for Django Auth
+        if import_log.import_type != "O" and field_name[-3:] != "ptr" and \
+            not field_name in ['password', 'date_joined', 'last_login']: 
+            if (direct and model and not field_object.blank) or (not getattr(field_object, "blank", True)):
+                field_matches = column_matches.filter(field_name=field_name)
+                match_in_header = False
+                if field_matches:
+                    for field_match in field_matches:
+                        if field_match.column_name.lower() in header_row:
+                            match_in_header = True
+                    if not match_in_header:
+                        errors += ["{0} is required but is not in your spreadsheet. ".format(field_object.verbose_name.title())]
+                else:
+                    errors += ["{0} is required but has no match.".format(field_object.verbose_name.title())]
     
     return errors
 
@@ -145,7 +149,7 @@ def match_columns(request, import_log_id):
             field_choices += (("simple_import_method__{0}".format(import_method),
                                "{0} (Method)".format(import_method)),)
     # User model should allow set password
-    if model_class == User:
+    if issubclass(model_class, User):
         field_choices += (("simple_import_method__{0}".format('set_password'),
                                "Set Password (Method)"),) 
     
@@ -248,6 +252,14 @@ def set_field_from_cell(import_log, new_object, header_row_field_name, cell):
                         setattr(new_object, header_row_field_name, choice[0])
         else:
             setattr(new_object, header_row_field_name, cell)
+    
+    
+def set_method_from_cell(import_log, new_object, header_row_field_name, cell):
+    """ Run a method from a import cell.
+    """
+    if (not header_row_field_name.startswith('simple_import_custom__') and
+            not header_row_field_name.startswith('simple_import_method__')):
+        pass
     elif header_row_field_name.startswith('simple_import_custom__'):
         new_object.set_custom_value(header_row_field_name[22:], cell)
     elif header_row_field_name.startswith('simple_import_method__'):
@@ -323,6 +335,20 @@ def do_import(request, import_log_id):
                         elif header_row_default[i]:
                             set_field_from_cell(import_log, new_object, header_row_field_names[i], header_row_default[i])
                 new_object.save()
+
+                for i, cell in enumerate(row):
+                    if header_row_field_names[i]: # skip blank
+                        if cell or header_row_null_on_empty[i]:
+                            set_method_from_cell(import_log, new_object, header_row_field_names[i], cell)
+                        elif header_row_default[i]:
+                            set_method_from_cell(import_log, new_object, header_row_field_names[i], header_row_default[i])
+
+                for i, cell in enumerate(row):
+                    if header_row_field_names[i]: # skip blank
+                        if cell or header_row_null_on_empty[i]:
+                            set_field_from_cell(import_log, new_object, header_row_field_names[i], cell)
+                        elif header_row_default[i]:
+                            set_field_from_cell(import_log, new_object, header_row_field_names[i], header_row_default[i])
                 
                 for key in new_object.simple_import_m2ms.keys():
                     value = new_object.simple_import_m2ms[key]
